#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from asposeimagingcloud.models.available_labels_list import AvailableLabelsList
from asposeimagingcloud.models.bmp_properties import BmpProperties
from asposeimagingcloud.models.detected_object import DetectedObject
from asposeimagingcloud.models.detected_object_list import DetectedObjectList
from asposeimagingcloud.models.dicom_properties import DicomProperties
from asposeimagingcloud.models.disc_usage import DiscUsage
from asposeimagingcloud.models.djvu_properties import DjvuProperties
from asposeimagingcloud.models.dng_properties import DngProperties
from asposeimagingcloud.models.eps_properties import EpsProperties
from asposeimagingcloud.models.error import Error
from asposeimagingcloud.models.error_details import ErrorDetails
from asposeimagingcloud.models.exif_data import ExifData
from asposeimagingcloud.models.file_versions import FileVersions
from asposeimagingcloud.models.files_list import FilesList
from asposeimagingcloud.models.files_upload_result import FilesUploadResult
from asposeimagingcloud.models.filter_properties_base import FilterPropertiesBase
from asposeimagingcloud.models.gif_properties import GifProperties
from asposeimagingcloud.models.image_duplicates import ImageDuplicates
from asposeimagingcloud.models.image_duplicates_set import ImageDuplicatesSet
from asposeimagingcloud.models.image_features import ImageFeatures
from asposeimagingcloud.models.imaging_response import ImagingResponse
from asposeimagingcloud.models.jfif_data import JfifData
from asposeimagingcloud.models.jpeg2000_properties import Jpeg2000Properties
from asposeimagingcloud.models.jpeg_properties import JpegProperties
from asposeimagingcloud.models.object_exist import ObjectExist
from asposeimagingcloud.models.odg_metadata import OdgMetadata
from asposeimagingcloud.models.odg_page import OdgPage
from asposeimagingcloud.models.odg_properties import OdgProperties
from asposeimagingcloud.models.png_properties import PngProperties
from asposeimagingcloud.models.psd_properties import PsdProperties
from asposeimagingcloud.models.rectangle import Rectangle
from asposeimagingcloud.models.search_context_status import SearchContextStatus
from asposeimagingcloud.models.search_result import SearchResult
from asposeimagingcloud.models.search_results_set import SearchResultsSet
from asposeimagingcloud.models.storage_exist import StorageExist
from asposeimagingcloud.models.storage_file import StorageFile
from asposeimagingcloud.models.svg_properties import SvgProperties
from asposeimagingcloud.models.tiff_frame import TiffFrame
from asposeimagingcloud.models.tiff_options import TiffOptions
from asposeimagingcloud.models.tiff_properties import TiffProperties
from asposeimagingcloud.models.web_p_properties import WebPProperties
from asposeimagingcloud.models.big_rectangular_filter_properties import BigRectangularFilterProperties
from asposeimagingcloud.models.bilateral_smoothing_filter_properties import BilateralSmoothingFilterProperties
from asposeimagingcloud.models.convolution_filter_properties import ConvolutionFilterProperties
from asposeimagingcloud.models.deconvolution_filter_properties import DeconvolutionFilterProperties
from asposeimagingcloud.models.file_version import FileVersion
from asposeimagingcloud.models.jpeg_exif_data import JpegExifData
from asposeimagingcloud.models.median_filter_properties import MedianFilterProperties
from asposeimagingcloud.models.small_rectangular_filter_properties import SmallRectangularFilterProperties
from asposeimagingcloud.models.gauss_wiener_filter_properties import GaussWienerFilterProperties
from asposeimagingcloud.models.gaussian_blur_filter_properties import GaussianBlurFilterProperties
from asposeimagingcloud.models.motion_wiener_filter_properties import MotionWienerFilterProperties
from asposeimagingcloud.models.sharpen_filter_properties import SharpenFilterProperties
